@@ -175,7 +175,7 @@ class IpAddr(object):
 
         """
         for line in text.split('\n'):
-            words = [ word for word in line.split(' ') if word is not '' ]
+            words = [ word for word in line.split(' ') if word != '' ]
             if words[0] == 'inet':
                 # use existing logic
                 self.v4 = words[1].split('/')[0]
@@ -228,7 +228,7 @@ class AbstractPlugin(object):
 
     _name = None
     _oneliner = 'No info found'
-    __version__ = '0.6.4'
+    __version__ = '0.6.5'
 
     def oneliner(self):
         """Return oneliner describing the plugin."""
